==> hindent-5.2.3-28-i686.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.2.3
id: hindent-5.2.3-KOyUjMub5uIGhe4RgC6tni
key: hindent-5.2.3-KOyUjMub5uIGhe4RgC6tni
license: BSD3
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
exposed: True
exposed-modules:
    HIndent HIndent.Types HIndent.Pretty
abi: b98bc2d207b404d8cbf196d5c7867b4a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hindent-5.2.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/hindent-5.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.2.3-KOyUjMub5uIGhe4RgC6tni
depends:
    base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd
    haskell-src-exts-1.19.1-7Ymk4sexwB7KzlRpbPSyAR
    monad-loops-0.4.3-H2ZtiK81hjvIHTjt5szwnX
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
    yaml-0.8.23.3-8FJZhPKX9fmLLFoNaNncOM
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hindent-5.2.3-35-i686.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.2.3
id: hindent-5.2.3-4oJlt2ymBDCIZFehuwfGNP
key: hindent-5.2.3-4oJlt2ymBDCIZFehuwfGNP
license: BSD3
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
exposed: True
exposed-modules:
    HIndent HIndent.Types HIndent.Pretty
abi: d185434681a4f558a262b24a53c04c49
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hindent-5.2.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/hindent-5.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.2.3-4oJlt2ymBDCIZFehuwfGNP
depends:
    base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd
    haskell-src-exts-1.19.1-7Ymk4sexwB7KzlRpbPSyAR
    monad-loops-0.4.3-H2ZtiK81hjvIHTjt5szwnX
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
    yaml-0.8.23.3-3BbiUBqxe192HmKg4jbbCV
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
